@@ -162,6 +162,11 @@ class ProjectTest(unittest.TestCase):
         comparison = self.project.compare_builds(self.build2.id, self.build.id)
         self.assertEqual('Cannot report regressions/fixes on a non-finished builds', comparison[0])
 
+    def test_compare_builds_from_same_project_force(self):
+        comparison = self.project.compare_builds(self.build2.id, self.build.id, force=True)
+        self.assertEqual({}, comparison['regressions'])
+        self.assertEqual({}, comparison['fixes'])
+
     def test_create_project(self):
         group = Squad().group('my_group')
         slug = 'test-create-project'
